searchData={"items":[{"type":"module","title":"LiveToast","doc":"LiveComponent for displaying toast messages.","ref":"LiveToast.html"},{"type":"function","title":"LiveToast.send_toast/7","doc":"Merges a new toast message into the current toast list.","ref":"LiveToast.html#send_toast/7"},{"type":"function","title":"LiveToast.toast_class_fn/1","doc":"Implement your own function to override the class of the toasts.\n\nExample:\n```elixir\ndefmodule MyModule do\n  def toast_class_fn(assigns) do\n    [\n      \"w-80 sm:w-96 z-50 p-2 rounded-md shadow origin-center overflow-hidden\",\n      assigns[:rest][:hidden] != true && \"flex\",\n      assigns[:kind] == :info && \"text-gray-800 bg-gray-50 dark:bg-gray-800 dark:text-gray-300\",\n      assigns[:kind] == :success &&\n        \"text-green-800 bg-green-50 dark:bg-gray-800 dark:text-green-400\",\n      assigns[:kind] == :error && \"text-red-800 bg-red-50 dark:bg-gray-800 dark:text-red-400\"\n    ]\n  end\nend\n\n# use it in your layout:\n#  \n```","ref":"LiveToast.html#toast_class_fn/1"},{"type":"function","title":"LiveToast.toast_group/1","doc":"toast_group/1 is just a small Phoenix.Component wrapper around the LiveComponent for toasts.\nYou can use the LiveComponent directly if you prefer, this is just a convenience.","ref":"LiveToast.html#toast_group/1"},{"type":"function","title":"Attributes - LiveToast.toast_group/1","doc":"* `flash` (`:map`) (required) - the map of flash messages.\n* `id` (`:string`) - the optional id of flash container. Defaults to `\"toast-group\"`.\n* `connected` (`:boolean`) - whether we're in a liveview or not. Defaults to `false`.\n* `corner` (`:atom`) - the corner to display the toasts. Defaults to `:top_right`.\n* `toast_class_fn` (`:any`) - function to override the look of the toasts. Defaults to `&LiveToast.toast_class_fn/1`.","ref":"LiveToast.html#toast_group/1-attributes"},{"type":"task","title":"mix docs.run","doc":"Run documentation server.","ref":"Mix.Tasks.Docs.Run.html"},{"type":"function","title":"Mix.Tasks.Docs.Run.run/1","doc":"","ref":"Mix.Tasks.Docs.Run.html#run/1"},{"type":"extras","title":"Live Toast","doc":"# Live Toast\n\n![CI](https://github.com/srcrip/live_toast/workflows/CI/badge.svg) [![Hex](https://img.shields.io/hexpm/v/live_toast)](https://hex.pm/packages/live_toast)\n\nLive Toast is a drop-in replacement for the flash system in Phoenix/LiveView.","ref":"readme.html"},{"type":"extras","title":"Installation - Live Toast","doc":"Add `live_toast` to your list of dependencies in the `mix.exs` of your Phoenix\napplication:\n\n```elixir\ndef deps do\n  [\n    {:live_toast, \"~> 0.3.0\"}\n  ]\nend\n```\n\nNext open up your `app.js` and import/setup the hook:\n\n```javascript\nimport { createLiveToastHook } from 'live_toast'\n\nlet liveSocket = new LiveSocket('/live', Socket, {\n  hooks: {\n    LiveToast: createLiveToastHook()\n  }\n})\n```\n\nThen, add `'../deps/live_toast/lib/**/*.*ex'` to your list of paths Tailwind will look for class names, in your\n`tailwind.config.js`:\n\n```javascript\n// assets/tailwind.config.js\n\nmodule.exports = {\n  content: [\n    './js/**/*.js',\n    '../lib/your_app_web.ex',\n    '../lib/your_app_web/**/*.*ex',\n    '../deps/live_toast/lib/**/*.*ex',\n  ]\n}\n```\n\nYour particular file will look different but all you need to do is make sure the last line is there.\n\nNote that the classes are currently hardcoded. Configuration of the toast components, and therefore there styling, are\non the roadmap. But the default styles should look pretty good in the mean time.\n\nFinally, replace your `<.flash_group />` component with the new ` `. It's most likely in your\n`app.html.heex`:\n\n```eex\n<!-- Remove this! -->\n<.flash_group flash={@flash} />\n\n<!-- And replace it with this: -->\n \n\n<%= @inner_content %>\n```\n\nAnd you're done! Note that it's very important to set `connected` based on whether we're in a LiveView or not. This\ncontrols toast/flash display on non-LiveView pages.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Live Toast","doc":"`LiveToast` will hijack the usual display of your flash messages, so they will continue to work as normal. You can\ncontinue to use flashes as normal, if you want to.\n\nHowever, one of the reasons to *not* use flash messages, is the Phoenix flash system only allows one message for each\nkind of flash. The toast pattern, alternatively, generally allows for multiple messages displayed to the user at at time.\n\n\nFrom a LiveView, you can now use `send_toast`:\n\n```elixir\ndefmodule YourApp.SomeLiveView do\n  def handle_event(\"submit\", _payload, socket) do\n  # you do some thing with the payload, then you want to show a toast, so:\n  LiveToast.send_toast(:info, \"Upload successful.\")\n\n  {:noreply, socket}\n  end\nend\n```\n\nOr you can use the helper function, `put_toast`, similar to how you may use `put_flash`:\n\n```elixir\ndefmodule YourApp.SomeLiveView do\n  def handle_event(\"submit\", _payload, socket) do\n    socket = socket\n    |> put_toast(:info, \"Upload successful.\")\n\n    {:noreply, socket}\n  end\nend\n```\n\n`put_toast` can take a `Phoenix.LiveView.Socket` or a `Plug.Conn`, so you can use the same thing in your live and\nnon-live pages.\n\n```elixir\ndefmodule YourApp.SomeController do\n  def create(conn, _params) do\n    conn\n    |> put_toast(:info, \"Upload successful.\")\n    |> render(:whatever)\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Configuration - Live Toast","doc":"You can define a custom toast class function, like so:\n\n```elixir\ndefmodule MyModule do\n  def toast_class_fn(assigns) do\n    [\n      \"w-80 sm:w-96 z-50 p-2 rounded-md shadow origin-center overflow-hidden\",\n      assigns[:rest][:hidden] != true && \"flex\",\n      assigns[:kind] == :info && \"text-gray-800 bg-gray-50 dark:bg-gray-800 dark:text-gray-300\",\n      assigns[:kind] == :success && \"text-green-800 bg-green-50 dark:bg-gray-800 dark:text-green-400\",\n      assigns[:kind] == :error && \"text-red-800 bg-red-50 dark:bg-gray-800 dark:text-red-400\"\n    ]\n  end\nend\n\n```\n\nAnd then use it to override the default styles:\n\n```heex\n \n```\n\nAnd that's pretty much it.","ref":"readme.html#configuration"},{"type":"extras","title":"Roadmap - Live Toast","doc":"Some of the stuff still to work on:\n\n- [ ] Improved docs\n- [ ] Configuration for the classes on toasts\n- [ ] more tests\n- [ ] More configuration for the animations\n- [ ] Ability to have more flashes than the default :error and :info (like a :warn)\n- [ ] Update a toast live (showing progress for example), and a recipe entry on this","ref":"readme.html#roadmap"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\n## [v0.1.0] (2024-03-06)\n\n🚀 Initial release.\n\n## [v0.2.0] (2024-03-08)\n\nBug fixes:\n- JS.Show on the flashes now correctly toggles them to display flex instead of block\n- The component functions properly when used in non-liveviews\n\n## [v0.3.0] (2024-03-12)\n\nBug fixes:\n- Fixing quite a few little problems here and there\n- Adding more configuration\n\n## [v0.4.0] (2024-05-11)\n\nMassive overhaul of look and feel.\n\n## [v0.4.1] (2024-05-11)\n\nDemo repo bug fixing.","ref":"changelog.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}